==> zio-aws-securityhub_2.13-5.17.116.1-sources.jar: zio/aws/securityhub/model/RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RuleGroupSourceStatelessRuleMatchAttributesSourcePorts(
    fromPort: Option[Integer] = None,
    toPort: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts = {
    import RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
      .builder()
      .optionallyWith(
        fromPort.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.fromPort)
      .optionallyWith(
        toPort.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.toPort)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly =
    zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
      .wrap(buildAwsValue())
}
object RuleGroupSourceStatelessRuleMatchAttributesSourcePorts {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts =
      zio.aws.securityhub.model
        .RuleGroupSourceStatelessRuleMatchAttributesSourcePorts(
          fromPort.map(value => value),
          toPort.map(value => value)
        )
    def fromPort: Option[Integer]
    def toPort: Option[Integer]
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ) extends zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly {
    override val fromPort: Option[Integer] = scala
      .Option(impl.fromPort())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val toPort: Option[Integer] = scala
      .Option(impl.toPort())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ): zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.157.2-sources.jar: zio/aws/securityhub/model/RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RuleGroupSourceStatelessRuleMatchAttributesSourcePorts(
    fromPort: Option[Integer] = None,
    toPort: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts = {
    import RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
      .builder()
      .optionallyWith(fromPort.map(value => value: java.lang.Integer))(
        _.fromPort
      )
      .optionallyWith(toPort.map(value => value: java.lang.Integer))(_.toPort)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly =
    zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
      .wrap(buildAwsValue())
}
object RuleGroupSourceStatelessRuleMatchAttributesSourcePorts {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts =
      zio.aws.securityhub.model
        .RuleGroupSourceStatelessRuleMatchAttributesSourcePorts(
          fromPort.map(value => value),
          toPort.map(value => value)
        )
    def fromPort: Option[Integer]
    def toPort: Option[Integer]
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ) extends zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly {
    override val fromPort: Option[Integer] =
      scala.Option(impl.fromPort()).map(value => value: Integer)
    override val toPort: Option[Integer] =
      scala.Option(impl.toPort()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
  ): zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.ReadOnly =
    new Wrapper(impl)
}
